Excel Spreadsheet — linkml documentation

# Excel Spreadsheet

This feature is still in development.

## Example Output

Using the Person LinkML schema as input, the generated Excel spreadsheet looks as follows: personinfo.xlsx

## Overview

You can create an Excel template of a LinkML schema as follows:

    gen-excel ~/path/to/personinfo.yaml --output ~/path/to/personinfo.xlsx

Currently, in the generated Excel workbook there can be one or more associated worksheets, each corresponding to classes from the LinkML schema.

Note that this works best for “flat” or denormalized schemas

Support to be added:

- If the range of a slot is an enum, the possible values for a field will be constrained through a dropdown

- Color schemes to indicate whether a field is required or recommended

- Constraints based on the range of a slot, e.g. constraining int fields to be numbers

- Tooltip notes describing what each field indicates

## Docs

### Command Line

#### gen-excel

Generate Excel representation of a LinkML model

    gen-excel [OPTIONS] YAMLFILE

Options

-o, --output <output>

  Name of Excel spreadsheet to be created

-f, --format <format>

  Output format (default=xlsx)

  Options

    xlsx

--metadata, --no-metadata

  Include metadata in output (default=–metadata)

--useuris, --metauris

  Include metadata in output (default=–useuris)

-im, --importmap <importmap>

  Import mapping file

--log_level <log_level>

  Logging level (default=WARNING)

  Options

    CRITICAL | ERROR | WARNING | INFO | DEBUG

--mergeimports, --no-mergeimports

  Merge imports into source file (default=mergeimports)

Arguments

YAMLFILE

  Required argument

### Code